@@ -1,36 +1,41 @@
 package DTL::Fast;
 use strict; use warnings FATAL => 'all'; 
-use parent 'Exporter';
-use Carp;
+use Exporter 'import';
 use Digest::MD5 qw(md5_hex);
 
 use 5.010;
-our $VERSION = '1.605'; # ==> ALSO update the version in the pod text below!
+our $VERSION = '1.606'; # ==> ALSO update the version in the pod text below!
+
+# loaded modules
+our %TAG_HANDLERS;
+our %FILTER_HANDLERS;
+our %OPS_HANDLERS;
+
+# known but not loaded modules
+our %KNOWN_TAGS;
+our %KNOWN_FILTERS;
+our %KNOWN_OPS;
+
+# modules hash to avoid duplicating on deserializing
+our %LOADED_MODULES;
 
 require XSLoader;
 XSLoader::load('DTL::Fast', $VERSION);
 
-use DTL::Fast::Template;
-use DTL::Fast::Cache::Runtime;
-use DTL::Fast::Cache::Serialized;
-
 our $RUNTIME_CACHE;
 our $SERIALIZED_CACHE;
 
 our @EXPORT_OK;
 
-# @todo Texts should be tossed by references
-# @todo These should be done via Cache class which can work with last modified date
-
 push @EXPORT_OK, 'get_template';
 sub get_template
 {
     my( $template_name, %kwargs ) = @_;
     
-    croak  "Template name was not specified" 
+    die  "Template name was not specified" 
         if not $template_name;
 
-    croak "Template directories array was not specified"
+    die "Template directories array was not specified"
         if
             not defined $kwargs{'dirs'}
             or ref $kwargs{'dirs'} ne 'ARRAY'
@@ -56,7 +61,7 @@ sub get_template
         }
         else
         {
-            croak  sprintf( <<'_EOT_', $template_name, join("\n", @{$kwargs{'dirs'}}));
+            die  sprintf( <<'_EOT_', $template_name, join("\n", @{$kwargs{'dirs'}}));
 Unable to find template %s in directories: 
 %s
 _EOT_
@@ -89,7 +94,7 @@ sub read_template
     my $template = undef;
     my $template_path = undef;
 
-    croak "Template directories array was not specified"
+    die "Template directories array was not specified"
         if not defined $kwargs{'dirs'}
             or not ref $kwargs{'dirs'}
             or not scalar @{$kwargs{'dirs'}}
@@ -159,34 +164,44 @@ sub _read_file
             and -r $template_path
         )
         {
-            if( open my $IF, '<', $template_path )
-            {
-                local $/ = undef;
-                $template = <$IF>;
-                close $IF;
-                last;
-            }
-            else
-            {
-                croak  sprintf(
-                    'Error opening file %s, %s'
-                    , $template_path
-                    , $!
-                );
-            }
+            $template = __read_file( $template_path );
+            last;
         }        
     }
     
     return ($template, $template_path);
 }
 
+
+sub __read_file
+{
+    my( $file_name ) = @_;
+    my $result;
+    
+    if( open my $IF, '<', $file_name )
+    {
+        local $/ = undef;
+        $result = <$IF>;
+        close $IF;
+    }
+    else
+    {
+        die  sprintf(
+            'Error opening file %s, %s'
+            , $file_name
+            , $!
+        );
+    }
+    return $result;
+}
+
 # result should be cached with full list of params
 push @EXPORT_OK, 'select_template';
 sub select_template
 {
     my( $template_names, %kwargs ) = @_;
     
-    croak  "First parameter must be a template names array reference" 
+    die  "First parameter must be a template names array reference" 
         if(
             not ref $template_names
             or ref $template_names ne 'ARRAY'
@@ -206,6 +221,40 @@ sub select_template
     return $result;
 }
 
+# registering tag as known
+push @EXPORT_OK, 'register_tag';
+sub register_tag
+{
+    my( %tags ) = @_;
+    
+    while( my( $slug, $module) = each %tags )
+    {
+        $DTL::Fast::KNOWN_TAGS{lc($slug)} = $module;
+    }
+    
+    return;
+}
+
+# registering tag as known
+push @EXPORT_OK, 'preload_tags';
+sub preload_tags
+{
+    require Module::Load;
+    
+    while( my( $keyword, $module) = each %KNOWN_TAGS )
+    {
+        Module::Load::load($module);
+    }
+    
+    return 1;
+}
+
+
+require DTL::Fast::Template;
+require DTL::Fast::Cache::Runtime;
+require DTL::Fast::Cache::Serialized;
+
+
 1;
 
 __END__ 
@@ -215,7 +264,7 @@ DTL::Fast - Perl implementation of Django templating language.
 
 =head1 VERSION
 
-Version 1.605
+Version 1.606
 
 =head1 SYNOPSIS
 
@@ -257,9 +306,9 @@ Goals of this implementation are:
 
 Current release implements almost all tags and filters documented on Django site.
 
-There are no speed optimizations done yet.
+There are no significant speed optimizations done yet.
 
-Internationalization, localization and caching are not yet implemented.
+Internationalization and localization are not yet implemented.
 
 =head1 PERL SIDE
 
@@ -275,7 +324,7 @@ Using DTL::Fast::Template constructor:
     my $tpl = DTL::Fast::Template->new(
         $template_text,                             # template itself
         'dirs' => [ $dir1, $dir2, ... ],            # optional, directories list to look for parent templates and includes
-        'ssi_dirs' => [ $ssi_dir1, $ssi_dir1, ...]  # optional, directories list to look for files included with ssi tag
+        'ssi_dirs' => [ $ssi_dir1, $ssi_dir1, ...]  # optional, directories list allowed to used in ssi tag (ALLOWED_INCLUDE_ROOTS in Django)
         'url_source' => \&uri_getter                # optional, reference to a function, that can return url template by model name (necessary for url tag)
     );
 
@@ -286,7 +335,7 @@ Using DTL::Fast::Template constructor:
     my $tpl = get_template(
         $template_path,                             # path to the template, relative to directories from second argument
         'dirs' => [ $dir1, $dir2, ... ],            # mandatory, directories list to look for parent templates and includes
-        'ssi_dirs' => [ $ssi_dir1, $ssi_dir1, ...]  # optional, directories list to look for files included with ssi tag
+        'ssi_dirs' => [ $ssi_dir1, $ssi_dir1, ...]  # optional, directories list allowed to used in ssi tag (ALLOWED_INCLUDE_ROOTS in Django)
         'url_source' => \&uri_getter                # optional, reference to a function, that can return url template by model name (necessary for url tag)
     );
     
@@ -299,7 +348,7 @@ when you are using C<get_template> helper function, framework will try to find t
     my $tpl = select_template(
         [ $template_path1, $template_path2, ...],   # paths to templates, relative to directories from second argument
         'dirs' => [ $dir1, $dir2, ... ],            # mandatory, directories list to look for parent templates and includes
-        'ssi_dirs' => [ $ssi_dir1, $ssi_dir1, ...]  # optional, directories list to look for files included with ssi tag
+        'ssi_dirs' => [ $ssi_dir1, $ssi_dir1, ...]  # optional, directories list allowed to used in ssi tag (ALLOWED_INCLUDE_ROOTS in Django)
         'url_source' => \&uri_getter                # optional, reference to a function, that can return url template by model name (necessary for url tag)
     );
     
@@ -340,6 +389,24 @@ or
     $context->set('name' => 'Sergey');
     print $tpl->render($context);
 
+=head2 register_tag
+
+    use DTL::Fast qw(register_tag);
+    
+    register_tag(
+        'mytag' => 'MyTag::Module'
+    );
+    
+This method registers or oferrides registered tag keyword with handler module. Module will be loaded when first encountered during template parsing. About handler modules you may read in L</Custom tags> section.
+
+=head2 preload_tags
+
+    use DTL::Fast qw(preload_tags);
+    
+    preload_tags();
+    
+Preloads all registered tags. Mostly for debugging purposes or persistent environment stability.
+
 =head2 Cache classes
 
 To do...
@@ -367,15 +434,33 @@ New tag, that works like C<firstof> tag, but checks if value is defined (not tru
 
 C<url> tag works a different way. Because there is no framework around, we can't obtain model's path the same way. But you may pass C<url_source> parameter into template constructor or C<get_template>/C<select_template> function. This parameter MUST be a reference to a function, that will return to templating engine url template by some 'model path' (first parameter of C<url> tag). Second parameter passed to the C<url_source> handler will be a reference to array of argument values (in case of positional arguments) or reference to a hash of arguments (in case of named ones). Url source handler may just return a regexp template by model path and templating engine will try to restore it with specified arguments. Or, you may restore it yourself, alter replacement arguments or do whatever you want. 
 
+=head3 warn
+
+    {% warn var1 var2 ... varn %}
+
+C<warn> tag is useful for development and debugging. Dumps variable using L<C<Data::Dumper>> to C<STDERR>.
+
+Without and argument dumps full context object.
+
 =head2 Filters
 
 This module supports all built-in filters documented on L<official Django site|https://docs.djangoproject.com/en/1.7/ref/templates/builtins/#built-in-filter-reference>. Don't forget to read L<incompatibilities|/INCOMPATIBILITIES WITH DJANGO TEMPLATES> and L<extensions|/EXTENSIONS OF DJANGO TEMPLATES> sections.
 
+=head3 numberformat
+
+    {% var1|numberformat %}
+    
+Formats 12345678.9012 as
+    
+    12 345 678.9012
+
+Split integer part of the number by 3 digits, separated by spaces.
+
 =head1 INCOMPATIBILITIES WITH DJANGO TEMPLATES
 
 =over
 
-=item * C<ssi> tag in Django uses absolute paths and C<ALLOWED_INCLUDE_ROOTS> configuration option. This library works separately and may be used with different frameworks. So, C<ssi> tag uses relative paths and you MUST specify additional template constructor parameter: C<ssi_dirs> which should be an array reference with list of dirs to search in.
+=item * Django's setting C<ALLOWED_INCLUDE_ROOTS> should be passed to tempalte constructor/getter as C<ssi_dirs> argument.
 
 =item * C<csrf_token> tag is not implemented, too well connected with Django.
 
@@ -488,10 +573,10 @@ Template parsing permormance with software cache wiping on each iteration:
 
     Benchmark: timing 5000 iterations of DTL::Fast  , Dotiac::DTL...
     
-    DTL::Fast  :  2 wallclock secs ( 1.31 usr +  0.75 sys =  2.06 CPU) @ 2428.36/s (n=5000)
-    Dotiac::DTL: 26 wallclock secs (11.40 usr + 13.01 sys = 24.41 CPU) @ 204.80/s (n=5000)
+    DTL::Fast  :  3 wallclock secs ( 2.47 usr +  1.05 sys =  3.51 CPU) @ 1424.10/s (n=5000)
+    Dotiac::DTL: 44 wallclock secs (21.86 usr + 20.39 sys = 42.25 CPU) @ 118.36/s (n=5000)
 
-C<DTL::Fast> parsing templates almost 12 times faster, than L<C<Dotiac::DTL>>.
+C<DTL::Fast> parsing templates 12 times faster, than L<C<Dotiac::DTL>>.
 
 To run this test, you need to alter L<C<Dotiac::DTL>> module and change declaration of C<my %cache;> to C<our %cache;>. 
     
@@ -499,21 +584,21 @@ Rendering of pre-compiled template (software cache):
 
     Benchmark: timing 3000 iterations of DTL::Fast  , Dotiac::DTL...
     
-    DTL::Fast  :  7 wallclock secs ( 7.29 usr +  0.00 sys =  7.29 CPU) @ 411.81/s (n=3000)
-    Dotiac::DTL: 13 wallclock secs (12.15 usr +  0.00 sys = 12.15 CPU) @ 246.85/s (n=3000)
+    DTL::Fast  : 17 wallclock secs (13.46 usr +  3.87 sys = 17.33 CPU) @ 173.09/s (n=3000)
+    Dotiac::DTL: 18 wallclock secs (17.38 usr +  0.00 sys = 17.38 CPU) @ 172.63/s (n=3000)
 
-Tests shows, that C<DTL::Fast> works 67% faster, than L<C<Dotiac::DTL>> in persistent environment.
+Tests shows, that C<DTL::Fast> works a bit faster, than L<C<Dotiac::DTL>> in persistent environment.
 
 =head2 CGI
 
 This test rendered test template many times by external script, invoked via C<system> call:
 
-    Benchmark: timing 500 iterations of Dotiac render , Fast render   ...
+    Benchmark: timing 300 iterations of Dotiac render     , Fast cached render, Fast render
     
-    Dotiac render : 57 wallclock secs ( 0.16 usr +  0.44 sys =  0.59 CPU) @ 843.17/s (n=500)
-    Fast render   : 62 wallclock secs ( 0.22 usr +  0.53 sys =  0.75 CPU) @ 668.45/s (n=500)
+    Dotiac render     : 40 wallclock secs ( 0.11 usr +  0.40 sys =  0.51 CPU) @ 583.66/s (n=300)
+    Fast render       : 55 wallclock secs ( 0.06 usr +  0.42 sys =  0.48 CPU) @ 619.83/s (n=300)
 
-Tests shows, that C<DTL::Fast> works 26% slower, than L<C<Dotiac::DTL>> in CGI environment.
+Tests shows, that C<DTL::Fast> works 40% slower, than L<C<Dotiac::DTL>> in CGI environment.
 
 =head2 DTL::Fast steps performance
 
