@@ -1,18 +1,17 @@
 package DTL::Fast::Expression::Operator::Binary::Ge;
-use strict; use utf8; use warnings FATAL => 'all'; 
+use strict; use utf8; use warnings FATAL => 'all';
 use parent 'DTL::Fast::Expression::Operator::Binary';
 
 $DTL::Fast::Expression::Operator::KNOWN{'>='} = __PACKAGE__;
 
 use Scalar::Util qw(looks_like_number);
-use DTL::Fast::Utils qw(has_method);
 
 sub dispatch
 {
     my( $self, $arg1, $arg2) = @_;
     my ($arg1_type, $arg2_type) = (ref $arg1, ref $arg2);
     my $result = 0;
-    
+
     if( looks_like_number($arg1) and looks_like_number($arg2))
     {
         $result = ($arg1 >= $arg2);
@@ -28,7 +27,7 @@ sub dispatch
 
         $result = ( scalar @$arg1 >= scalar @$arg2 );
     }
-    elsif( has_method($arg1, 'compare'))
+    elsif( UNIVERSAL::can($arg1, 'compare'))
     {
         $result = ( $arg1->compare($arg2) > -1 );
     }
@@ -36,8 +35,8 @@ sub dispatch
     {
         $result = ($arg1 ge $arg2);
     }
-    
+
     return $result;
 }
 
-1;
\ No newline at end of file
+1;
