@@ -1,13 +1,18 @@
 package DTL::Fast::Expression::Operator::Unary;
 use strict; use utf8; use warnings FATAL => 'all'; 
 
-use DTL::Fast::Template;
+use DTL::Fast::Expression::Operator::Unary::Not;
+
+# not in Django
+use DTL::Fast::Expression::Operator::Unary::Defined;
 
 sub new
 {
     my( $proto, $argument, %kwargs ) = @_;
     $kwargs{'a'} = $argument;
-    $DTL::Fast::Template::CURRENT_TEMPLATE->{'modules'}->{$proto} //= $proto->VERSION // DTL::Fast->VERSION;
+    $kwargs{'_template'}->{'modules'}->{$proto} //= $proto->VERSION // $DTL::Fast::VERSION;
+
+    delete $kwargs{'_template'};
     
     return bless {%kwargs}, $proto;
 }
