@@ -1,6 +1,6 @@
 package DTL::Fast::Tag::Ifchanged;
-use strict; use utf8; use warnings FATAL => 'all'; 
-use parent 'DTL::Fast::Tag';  
+use strict; use utf8; use warnings FATAL => 'all';
+use parent 'DTL::Fast::Tag';
 
 $DTL::Fast::TAG_HANDLERS{'ifchanged'} = __PACKAGE__;
 
@@ -13,10 +13,18 @@ sub get_close_tag{ return 'endifchanged'; }
 sub parse_parameters
 {
     my $self = shift;
-    
+
     $self->add_branch();
-    $self->{'watches'} = $self->parse_sources($self->{'parameter'});
-    
+
+    if ( $self->{'parameter'})
+    {
+        $self->{'watches'} = $self->parse_sources($self->{'parameter'});
+    }
+    else
+    {
+        $self->{'watch_content'} = 1;
+    }
+
     return $self;
 }
 
@@ -26,19 +34,17 @@ sub add_chunk
 {
     my $self = shift;
     my $chunk = shift;
-    
+
     $self->{'branches'}->[-1]->add_chunk($chunk);
-    
+
     return $self;
 }
 
 #@Override
 sub parse_tag_chunk
 {
-    my $self = shift;
-    my $tag_name = shift;
-    my $tag_param = shift;
-    
+    my( $self, $tag_name, $tag_param ) = @_;
+
     my $result = undef;
 
     if( $tag_name eq 'else' )
@@ -49,7 +55,7 @@ sub parse_tag_chunk
     {
         $result = $self->SUPER::parse_tag_chunk($tag_name, $tag_param);
     }
-    
+
     return $result;
 }
 
@@ -59,33 +65,56 @@ sub render
     my $self = shift;
     my $context = shift;
     my $result = '';
-  
+
     my $forloop = $context->get('forloop');
-    
+
     if( defined $forloop )
     {
-        if( $forloop->{'first'} ) # first pass
+        if( $self->{'watch_content'} ) # slow behavior
         {
-            $self->update_preserved($context);
-        }
-        else
-        {
-            if( $self->watches_changed($context) )
+            $result = $self->{'branches'}->[0]->render($context);
+            if(
+                $forloop->{'first'}                             # first pass
+                or $result ne $self->{'last_iteration_content'} # content changed
+            )
             {
-                $result = $self->{'branches'}->[0]->render($context);
-                $self->update_preserved($context);
+                $self->{'last_iteration_content'} = $result;
             }
             elsif( scalar @{$self->{'branches'}} > 1 )
             {
                 $result = $self->{'branches'}->[1]->render($context);
             }
+            else
+            {
+                $result = '';
+            }
+        }
+        else
+        {
+            if( $forloop->{'first'} ) # first pass
+            {
+                $self->update_preserved($context);
+                $result = $self->{'branches'}->[0]->render($context);
+            }
+            else
+            {
+                if( $self->watches_changed($context) )
+                {
+                    $result = $self->{'branches'}->[0]->render($context);
+                    $self->update_preserved($context);
+                }
+                elsif( scalar @{$self->{'branches'}} > 1 )
+                {
+                    $result = $self->{'branches'}->[1]->render($context);
+                }
+            }
         }
     }
     else
     {
         warn "ifchanged tag can be rendered only inside for loop";
     }
-    
+
     return $result;
 }
 
@@ -99,7 +128,7 @@ sub watches_changed
     {
         my $watch = $self->{'watches'}->[$i]->render($context);
         my $preserve = $self->{'preserved'}->[$i];
-        
+
         if( not DTL::Fast::Expression::Operator::Binary::Eq::dispatch($self, $watch, $preserve))
         {
             $result = 1;
@@ -114,21 +143,21 @@ sub update_preserved
 {
     my $self = shift;
     my $context = shift;
-    
+
     $self->{'preserved'} = [(
         map{ $_->render($context) } @{$self->{'watches'}}
     )];
-    
+
     return $self;
 }
 
 sub add_branch
 {
     my $self = shift;
-    
+
     $self->{'branches'} //= [];
     push @{$self->{'branches'}}, DTL::Fast::Renderer->new();
     return $self;
 }
 
-1;
\ No newline at end of file
+1;
